/*
  $Id: QuotaTypeData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;

/**
	This class holds information about different QuotaTypes.
	
	@author enell
	@version 2.0
	@see <a href="../../../../../../html/developer/api/data_api.quota.html">Developer documentation: Quota and disk usage</a>
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
	@hibernate.class table="`QuotaTypes`" lazy="false"
*/
public class QuotaTypeData
	extends BasicData
	implements NameableData, SystemData, RegisteredData
{
	
	public QuotaTypeData()
	{}
	
	/*
		From the Nameable interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}

	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	
	/*
		From the SystemData interface
		-------------------------------------------
	*/
	private String systemId;
	@Override
	public String getSystemId()
	{
		return systemId;
	}
	public void setSystemId(String systemId)
	{
		this.systemId = systemId;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private boolean secondaryLocation;
	/**
		If this quota type can use disk quota in the secondary location or not.
		
		@hibernate.property column="`secondary_location`" type="boolean" not-null="true" update="false"
	*/
	public boolean getSecondaryLocation()
	{
		return secondaryLocation;
	}
	public void setSecondaryLocation(boolean secondaryLocation)
	{
		this.secondaryLocation = secondaryLocation;
	}
	
}
