/*
  $Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

import net.sf.basedb.core.data.annotations.AnnotationLink;

/**
	This class holds the link between experiments and
	raw bioassays including an annotation set that is
	representing the experimental factor values.
	
	@author Nicklas
	@since 3.6
	@see net.sf.basedb.core.RootRawBioAssay
	@hibernate.class table="`RootRawBioAssays`" lazy="true"
*/
public class RootRawBioAssayData
	extends BasicData
	implements AnnotatableData, NameableData
{
	public RootRawBioAssayData()
	{}

	/*
		From the AnnotatableData interface
		-------------------------------------------
	*/
	private AnnotationSetData annotationSet;
	@Override
	public AnnotationSetData getAnnotationSet()
	{
		return annotationSet;
	}
	@Override
	public void setAnnotationSet(AnnotationSetData annotationSet)
	{
		this.annotationSet = annotationSet;
	}
	@Override
	public Set<AnnotationLink> getAnnotations()
	{
		return null;
	}
	void setAnnotations(Set<AnnotationLink> annotations)
	{}
	// -------------------------------------------
	/*
		From the NameableData interface
		-------------------------------------------
	*/	
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	
	@Override
	public void setName(String name)
	{
		this.name = name;
	}
	
	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------

	private ExperimentData experiment;
	/**
		Get the experiment this root raw bioassay belongs to.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`experiment_id`" not-null="true" unique-key="RootRawBioAssay_uniquebioassay"
	*/
	public ExperimentData getExperiment()
	{
		return experiment;
	}
	public void setExperiment(ExperimentData experiment)
	{
		this.experiment = experiment;
	}

	private RawBioAssayData rawBioAssay;
	/**
		Get the raw bioassay root raw bioassay is derived from.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`rawbioassay_id`" not-null="true" unique-key="RootRawBioAssay_uniquebioassay"
	*/
	public RawBioAssayData getRawBioAssay()
	{
		return rawBioAssay;
	}
	public void setRawBioAssay(RawBioAssayData rawBioAssay)
	{
		this.rawBioAssay = rawBioAssay;
	}

}
