/**
	$Id$

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager.filter;

import net.sf.basedb.util.extensions.manager.ExtensionsFile;
import net.sf.basedb.util.extensions.manager.ProcessResults;
import net.sf.basedb.util.extensions.manager.processor.MarkAsProcessedProcessor;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation that passes all extension files that 
	has been processed according to the information in the given
	ProcessResults object. Eg. if the {@link ProcessResults#getResults(ExtensionsFile)}
	returns null or an actual object. This filter is primarly inteded to be used
	together with the {@link MarkAsProcessedProcessor}, but may have other uses as well.

	@author Nicklas
	@since 3.0
	@base.modified $Date$
*/
public class WasProcessedFilter 
	implements Filter<ExtensionsFile>
{

	private final ProcessResults results;
	
	public WasProcessedFilter(ProcessResults results)
	{
		this.results = results;
	}
	
	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(ExtensionsFile xtFile) 
	{
		return results.getResults(xtFile) != null;
	}
	// ---------------------------
}
