/**
	$Id $

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.json;

import java.util.Collection;
import java.util.Iterator;

import org.json.simple.JSONArray;

/**
	Utility functions for working with JSON data.
	@author nicklas
	@since 3.3
*/
public class JsonUtil 
{

	/**
		Convert a collection of objects to an array with JSON-compatible
		objects. The converter may be null if the objects in the collection
		are already JSON-compatible.
		
		@param objects The collection of objects to convert and place in the array
		@param converter An optional converter if needed
	 	@return A JSON array with the converted objects, if the collection is null
	 		or empty an empty array is returned
	*/
	public static <T> JSONArray toArray(Collection<T> objects, JsonConverter<? super T> converter)
	{
		return toArray(objects != null ? objects.iterator() : null, converter);
	}
	
	/**
		Convert all objects returned by the iterator to an array with JSON-compatible
		objects. The converter may be null if the objects in the collection
		are already JSON-compatible.
		
		@param it An iterator returning the objects to convert and place in the array
		@param converter An optional converter if needed
	 	@return A JSON array with the converted objects, if the iterator is null
	 		or empty an empty array is returned
	*/
	@SuppressWarnings("unchecked")
	public static <T> JSONArray toArray(Iterator<T> it, JsonConverter<? super T> converter)
	{
		JSONArray json = new JSONArray();
		if (it != null)
		{
			if (converter == null) converter = new IdentityConverter<T>();
			while (it.hasNext())
			{
				json.add(converter.convert(it.next()));
			}
		}
		return json;
	}
	
}
