/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Quantities = function()
{
	var quantities = {};
	
	/**
		Initialize the page.
	*/
	quantities.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			Buttons.addClickHandler('btnSave', quantities.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabValidator('settings.info', quantities.validateQuantity);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'QUANTITY', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnNewUnit', quantities.newUnit, attributes)
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'QUANTITY'};
			var tableAttributes = {'table-id': 'quantities'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}


	// Add event handlers to the 'new unit' icons
	quantities.initElements = function(element, autoInit)
	{
		if (autoInit == 'new-unit')
		{
			Buttons.addClickHandler(element, quantities.newUnit);
		}
	}
	
	quantities.newUnit = function(event)
	{
		var quantityId = Data.get(event.currentTarget, 'item-id');
		Items.newItem('UNIT', '&quantity_id='+quantityId);
	}

	
	quantities.validateQuantity = function()
	{
		var frm = document.forms['quantity'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		if (Strings.trim(frm.referenceUnit.value) == '')
		{
			Forms.showNotification(frm.referenceUnit, 'You must enter a reference unit');
			return false;
		}
		return true;
	}

	// Submit the form
	quantities.save = function()
	{
		var frm = document.forms['quantity'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	return quantities;
}();

Doc.addElementInitializer(Quantities.initElements);
Doc.onLoad(Quantities.initPage);
