/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var EventTypes = function()
{
	var eventTypes = {};
	
	/**
		Initialize the page.
	*/
	eventTypes.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', eventTypes.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', eventTypes.validateEventType);
			
			// Ordinal
			Events.addEventHandler('ordinal', 'keypress', Events.integerOnly);

			// Protocol type
			Buttons.addClickHandler('protocoltype_id.select', eventTypes.selectProtocolType);
			Events.addEventHandler('protocoltype_id', 'base-selected', eventTypes.setProtocolTypeCallback);

		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var plateTypeId = Data.get('page-data', 'platetype-id');
			var attributes = {'item-type': 'PLATEEVENTTYPE', 'item-id': itemId, 'extra-url': '&platetype_id='+plateTypeId};

			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'PLATEEVENTTYPE'};
			var tableAttributes = {'table-id': 'eventtypes'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);

			TabControl.addTabActivateListener('main.properties', eventTypes.viewPlateTypeProperties);
		}
	}
	
	eventTypes.viewPlateTypeProperties = function()
	{
		var frm = document.forms['eventtypes'];
		var plateTypeId = frm.platetype_id.value;
		var url = '../index.jsp?ID='+App.getSessionId();
		url += '&cmd=ViewItem&item_id='+plateTypeId;
		url += '&tab=properties';
		location.replace(url);
	}

	eventTypes.validateEventType = function()
	{
		var frm = document.forms['eventtype'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		else if (Strings.trim(frm.ordinal.value) == '')
		{
			Forms.showNotification(frm.ordinal, 'You must enter an ordinal');
			return false;
		}
		return true;
	}

	// Submit the form
	eventTypes.save = function()
	{
		var frm = document.forms['eventtype'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	
	eventTypes.selectProtocolType = function()
	{
		var frm = document.forms['eventtype'];
		var protocolType = Data.get('protocoltype_id', 'protocol-type-filter');
		var url = '&resetTemporary=1&tmpfilter:INT:itemType='+protocolType;
		if (frm.protocoltype_id.length > 1) 
		{
			url += '&item_id='+frm.protocoltype_id[1].value;
		}
		Dialogs.selectItem('ITEMSUBTYPE', 'protocoltype_id', 0, url);
	}
	
	eventTypes.setProtocolTypeCallback = function(event)
	{
		var frm = document.forms['eventtype'];
		var list = frm.protocoltype_id;
		if (list.length < 2 || list[1].disabled)
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
	}


	return eventTypes;
}();

Doc.onLoad(EventTypes.initPage);
